package com.nationrel.modules.fta.util;

import com.nationrel.modules.fta.constant.FtaConstants;
import com.nationrel.modules.fta.entity.FtaAnalysis;
import com.nationrel.modules.fta.entity.FtaEdge;
import com.nationrel.modules.fta.entity.FtaNode;
import com.nationrel.modules.fta.general.domain.enums.fta.FtaNodeEnum;
import com.nationrel.modules.fta.general.domain.enums.reliaqube.ReliaqubeParamDataCheckEnum;
import com.nationrel.modules.fta.general.exception.DescribeException;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.sql.*;
import java.util.Date;
import java.util.List;

@Component
public class JDBC2Util {

    public static void batchAnalysisInsert(List<FtaAnalysis> analysisList, String mysqlUrl, String mysqlUserName, String mysqlPassword, Integer languageKey) {
        //1.导入驱动jar包
        //2.注册驱动(mysql5之后的驱动jar包可以省略注册驱动的步骤)
        //Class.forName("com.mysql.jdbc.Driver");
        //3.获取数据库连接对象
        Connection conn = null;
        PreparedStatement pstmt = null;
        try {
            //"&rewriteBatchedStatements=true",一次插入多条数据，只插入一次
            conn = DriverManager.getConnection(mysqlUrl.split(" \\?")[0] + "&rewriteBatchedStatements=true", mysqlUserName, mysqlPassword);
            conn.setAutoCommit(false);
            //4.定义sql语句
            String sql = "insert into fta_analysis (analysis_id,analysis_name,project_id,create_by,father_id,level) values(?,?,?,?,?,?)";
            //5.获取执行sql的对象PreparedStatement
            pstmt = conn.prepareStatement(sql);
            int resultNum = 0;
            //6.不断产生sql
            for (int i = 0, size = analysisList.size(); i < size; i++) {
                FtaAnalysis analysis = analysisList.get(i);
                if (i != 0 && i % FtaConstants.MAX_BATCH_NUMMAX == 0) {
                    pstmt.executeBatch();
                    pstmt.clearBatch();
                    resultNum = 0;
                }
                resultNum++;
                pstmt.setString(1, analysis.getAnalysisId());
                pstmt.setString(2, analysis.getAnalysisName());
                pstmt.setString(3, analysis.getProjectId());
                pstmt.setString(4, analysis.getCreateBy());
                pstmt.setString(5, analysis.getFatherId());
                pstmt.setInt(6, analysis.getLevel());
                pstmt.addBatch();
            }
            //7.往数据库插入一次数据
            if (resultNum > 0) {
                pstmt.executeBatch();
            }
            conn.commit();//执行完后，手动提交事务
            conn.setAutoCommit(true);//再把自动提交打开，避免影响其他需要自动提交的操作
        } catch (SQLException e) {
            e.printStackTrace();
            throw new DescribeException(ReliaqubeParamDataCheckEnum.请检查数据, languageKey);
        } finally {
            //8.释放资源
            //避免空指针异常
            if (pstmt != null) {
                try {
                    pstmt.close();
                } catch (SQLException e) {
                    e.printStackTrace();
                }
            }
            if (conn != null) {
                try {
                    conn.close();
                } catch (SQLException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public static Timestamp getTimestamp(Date date) {
        if (date != null) {
            return new Timestamp(date.getTime());
        }
        return null;
    }

}
